Calculates a new nearest neighbour fit based on a new order from a map object
generated by calc.maps.pc, calc.maps.sphere or
estimate.map
recalc.nnfit.from.map(estmap, mapobject, header = TRUE)A list with the elements:
Sum over all markers of the nearest neighbour fits.
The nearest neighbour fit for each marker.
Meanv of the nearest neighbour fits over all markers.
A character string indicating the name of a comma separated value file with the first column containing marker names in the order of their estimated position.
A map object generated by calc.maps.pc,
calc.maps.sphere or estimate.map.
Logical argument indicating whether the .csv file estmap
contains headers - default is TRUE
Reads in a new estimated order, reorders the distance map and LOD scores by the new order and recalculates the nearest neighbour fit.
calc.maps.pc, calc.maps.sphere, estimate.map, calc.nnfit